<?php

namespace Litecms\Product\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Product\Actions\ProductExim;
use Litecms\Product\Http\Requests\ProductEximRequest;

/**
 * Admin web controller class.
 */
class ProductEximController extends BaseController
{
    /**
     * Action controller function for product.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ProductEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = ProductExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product:product.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('product/product/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/product/' . $exim))
                ->redirect();
        }
    }
}
