<?php

namespace Litecms\Product\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Product\Actions\ProductReport;
use Litecms\Product\Http\Requests\ProductReportRequest;

/**
 * Admin web controller class.
 */
class ProductReportController extends BaseController
{
    /**
     * Action controller function for product.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ProductReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Product::class);
            $data = ProductReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::product.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('product/product/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/product/' . $report))
                ->redirect();
        }
    }
}
