<?php

namespace Litecms\Product\Http\Controllers;

use Exception;
use Litecms\Product\Actions\ProductWorkflow;
use Litecms\Product\Http\Requests\ProductWorkflowRequest;
use Litecms\Product\Http\Resources\ProductResource;
use Litecms\Product\Models\Product;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class ProductWorkflowController extends BaseController
{
    /**
     * Action controller function for product.
     *
     * @param Model $product
     * @param action next action for the product.
     *
     * @return Response
     */
    public function __invoke(ProductWorkflowRequest $request, Product $product, $trasition)
    {
        try {
            $product = ProductWorkflow::run($request, $product, $trasition);
            $data = new ProductResource($product);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::product.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('product/product/' . $product->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/product/' . $product->getRouteKey()))
                ->redirect();
        }
    }
}
