<?php

namespace Litecms\Product\Policies;

use Litecms\Product\Models\Product;
use Litepie\User\Interfaces\UserPolicyInterface;

trait ProductAction
{

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('product.product.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Product $product) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('product.product.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('product.product.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Product $product)
    {


        if ($authUser->canDo('product.product.action.delete')) {
            return true;
        }

        return false;
    }


}
