<?php

namespace Litecms\Product\Policies;

use Litecms\Product\Models\Product;
use Litepie\User\Interfaces\UserPolicyInterface;

trait ProductWorkflow
{

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function submit(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function publish(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unpublish(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function archive(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unarchive(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function reject(UserPolicyInterface $authUser, Product $product)
    {
        if ($authUser->canDo('product.product.reject')) {
            return true;
        }

        return false;
    }

}
